function [xgiro,arf,xarf]=giro_arfada(ficheroHidrostatica,ficheroLineasAgua,peso,Xg,Zg,hang,dang,alfa,densidad,varargin)

% Este programa calcula la posicin longitudinal cuando el barco empieza el
% giro. Adems determina si en algn momento anterior al giro se producir
% el efecto indeseable de la arfada.
%
% giro_arfada(ficheroHidrostatica,ficheroLineasAgua,peso,Xg,Zg,hang,dang,alfa,densidad,varargin);
%
% Variables de entrada:
% ficheroHidrostatica  nombre del fichero excel que contiene los clculos
%                      hidrostticos del barco en posicin de adrizado
% ficheroLineasAgua   nombre del fichero excel que contiene los datos de las semimangas
%                     para cada seccin y calado
% peso variable que indica el peso real del barco
% Xg posicin longitudinal del centro de pesos
% Zg posicin vertical del centro de pesos
% hang altura de la anguila
% dang distancia desde la proa de la anguila a la proa del barco
% alfa inclinacin de la grada
% densidad del lquido donde se sumerge el barco
%                densidad agua dulce=1
%                densidad agua salada=1.025
% varargin
%           posibilidad '1', dg (distancia mojada de la grada),
%           posibilidad '2', caladok (calado en el punto k de la grada)
%           dibujo si la variable vale 1 se mostrar la posicin del centro
%           de empuje, si vale cero no
%
% Variables de salida:
% xgiro  posicin longitudinal donde comienza el giro del barco
% arf    variable que indica si hay arfada (arf='1') o no (arf='0')
% xarf   en caso de que haya arfada indica en qu posicin longitudinal


% Definimos el calado en el punto k y la distancia de grada mojada

if varargin{1}=='1'
    dg=varargin{2};
    caladok=sin(alfa)*dg;
elseif varargin{1}=='2'
    caladok=varargin{2};
    dg=caladok/sin(alfa);
end

if nargin~=12
    uiwait(msgbox('Faltan variables de entrada en el programa giro_arfada.m','Revisar datos de entrada','error'));
    return;
else
    dibujo=varargin{3};
end

% Lee las variables hidrostticas calculadas

numeric=xlsread(ficheroHidrostatica);
[nh,mh]=size(numeric);

% Lee las alturas de las lneas de agua, las secciones, y las semimangas

semimangas=xlsread(['./Lneas de Agua/',ficheroLineasAgua]);
[n,m]=size(semimangas);

% secciones, desde i0=1 hasta i0=m-1
x=semimangas(1,2:m);

% alturas
z=semimangas(2:n,1);

% semimangas
y=semimangas(2:n,2:m);

% inicializamos los valores de la arfada
arf='0';
xarf=-1;
xgiro=-1;

% Calculamos distancias para el clculo del momento del empuje y del
% momento del peso

d1=hang/sin(alfa);
d3=dg*cos(alfa);
d4p=Xg/cos(alfa);

% Ampliamos x para que permita ir ms all de la eslora mxima

xaux=[x,x(m-1)+0.5:0.5:z(1)/tan(alfa)+10];
maux=length(xaux);


% Bucle que va sumergiendo el barco deslizandolo sobre la grada, subido
% en la anguila

for i0=1:maux
    
    % Comprobamos la condicin de Arfada
    
    d2=xaux(i0)/cos(alfa);
    
    % calculamos el empuje y centro de empuje para una posicin
    % determinada del barco en la botadura
    
    if i0>m-1
        [empuje,centro_empuje]=hidrostatica_alfa(m-1,xaux(i0),alfa,semimangas,densidad);
    else
        [empuje,centro_empuje]=hidrostatica_alfa(i0,xaux(i0),alfa,semimangas,densidad);
    end
    
    
    d4e=centro_empuje(1)/cos(alfa);
    de=d1+d2-d3-d4e;
    dp=d1+d2-d3-d4p;
    
    MomentoEmpuje=empuje*de;
    MomentoPeso=peso*dp;
    
    if MomentoPeso>MomentoEmpuje
        arf='1';
        xarf=xaux(i0);
        uiwait(msgbox('Peligro, se da la Arfada ','Arfada','error'));
        return;
    end
    
    % Comprobamos la condicin de Hundimiento
    
    naux=round(0.25*(m-1));
    yaux=y(:,1:naux);
    ind=find(yaux'~=0);
    naux=ceil(ind(1)/naux);  % z(naux) contiene el calado mximo en popa
    
    if (xaux(i0)*sin(alfa)+0.5)>=z(naux)
        
        uiwait(msgbox('Peligro, se hunde el barco por Inundacin ','Inundacin','error'));
        return;
        
    end
    
    % Calculamos donde se da el giro
    
    % obtenemos la eslora de flotacin
    
    [v]=interpolacion_variables_hidrostaticas(peso,ficheroHidrostatica);
    Lf=v(14);
    
    % distancia desde el centro de pesos longitudinal a la proa de la anguila
    
    dpGiro=Lf-dang-Xg;
    
    % distancia desde el centro de empuje longitudinal a la proa de la
    % anguila
    
    deGiro=Lf-dang-centro_empuje(1);
    
    % calculamos el momento del peso para el giro
    
    MomentoPesoGiro=peso*(dpGiro*cos(alfa)+(Zg+hang)*sin(alfa));
    MomentoEmpujeGiro=empuje*(deGiro*cos(alfa)+(centro_empuje(3)+hang)*sin(alfa));
    
    
    if dibujo==1
        dibujo_barco_grada(i0,xaux(i0),alfa,semimangas,densidad,Xg,Zg);
    end
    
    if MomentoEmpujeGiro>=MomentoPesoGiro
        
        xgiro=xaux(i0);
        IconoOk=imread('IconoOk.jpg');
        uiwait(msgbox(['El giro se da correctamente a x=',num2str(xgiro),blanks(3),'metros de popa'],'Punto de Giro','custom',IconoOk));    
        return;
    end
    
end




