function [v]=interpolacion_variables_hidrostaticas(peso,fichero)

% Esta funcin interpola linealmente los valores de las variables
% hidrostticas correspondientes a un peso dado, que entra como 
% variable de entrada en la columna de desplazamiento.
% Las variables hidrostticas consideradas son:
% Calado
% Aw rea de la flotacin
% TCI toneladas por centmetro de inmersin
% Xf coordenada longitudinal del centro de flotacin
% V volumen de carena
% D desplazamiento
% KB coordenada vertical del centro de carena
% XB coordenada longitudinal del centro de carena
% BMt radio metacntrico transversal
% BMl radio metacntrico longitudinal
% MTC momento para alterar el trimado un centmetro
%
% [v]=interpolacion_variables_hidrostaticas(peso,fichero)
% Variables de entrada:
% peso del barco, que se supone conocido
% fichero nombre del fichero que contiene los valores de las 
%         variables hidrostticas a diferentes calados
%
% Variables de salida:
% v vector que contiene los valores interpolados de las diferentes
%   variables hidrostticas consideradas


% Lee las variables hidrostticas calculadas

numeric=xlsread(fichero);
[n,m]=size(numeric);

% Introduce el peso en la columna de desplazamiento y calcula entre que
% dos valores de desplazamiento se encuentra el peso

ind=find(numeric(:,6)<peso);
ind_sup=ind(1)-1;
ind_inf=ind(1);

% Interpolamos cada una de las variables

v=numeric(ind_inf,:)+((numeric(ind_sup,:)-numeric(ind_inf,:))...
    /(numeric(ind_sup,6)-numeric(ind_inf,6)))*(peso-numeric(ind_inf,6));


