function s=obtener_secciones(fichero)

% Esta funcin lee las secciones de un barco en una variable 
% de tipo estructura a partir del nombre de un fichero .xls
% s=obtener_secciones(fichero);
% Variables de entrada:
% fichero nombre del archivo que contiene el fichero .xls 
% Variables de salida:
% s estructura que contiene las diferentes secciones del barco
%   Sus campos son los siguientes:
%   s.x  posicin espacial x de la seccin
%   s.numero  nmero de puntos de control en la seccin considerada
%   s.puntos coordenadas (y,z) de los puntos de control
%   s.tipo tipo de poligonal entre un punto y el siguiente. Puede
%          ser paralela al eje y, paralela al eje z, u oblicua
%   s.poligonal informacin necesaria para construir la poligonal
%   s.limites indica de dnde a dnde se extiende cada lnea de la
%             poligonal


fichero=['./Secciones de Barcos/',fichero];
datos=xlsread(fichero);

n=size(datos,1);
ns=0;  % nmero de secciones

% Leemos las secciones

s=struct;
m=1;
while m<n

    ns=ns+1;
    s(ns).x=datos(m,1);
    s(ns).numero=round(datos(m,2));
    s(ns).puntos=datos(m+1:m+s(ns).numero,:);

    % calcula la poligonal entre cada dos puntos

    s(ns).tipo='';
    s(ns).poligonal=[];
    s(ns).limites=[];

    for j=1:s(ns).numero-1

        puntoA=s(ns).puntos(j,:);
        puntoB=s(ns).puntos(j+1,:);

        if abs(puntoA(1)-puntoB(1))<10^(-15)
            s(ns).tipo=strvcat(s(ns).tipo,'Paralela al Eje z');
            s(ns).poligonal=[s(ns).poligonal;[puntoA(1),0]];
            s(ns).limites=[s(ns).limites;[min(puntoA(2),puntoB(2)),max(puntoA(2),puntoB(2))]];
        elseif abs(puntoA(2)-puntoB(2))<10^(-15)
            s(ns).tipo=strvcat(s(ns).tipo,'Paralela al Eje y');
            s(ns).poligonal=[s(ns).poligonal;[puntoA(2),0]];
            s(ns).limites=[s(ns).limites;[min(puntoA(1),puntoB(1)),max(puntoA(1),puntoB(1))]];
        else
            s(ns).tipo=strvcat(s(ns).tipo,'Oblicua');
            a=(puntoA(1)-puntoB(1))/(puntoA(2)-puntoB(2));
            b=puntoA(1)-a*puntoA(2);
            s(ns).poligonal=[s(ns).poligonal;[a,b]];
            s(ns).limites=[s(ns).limites;[min(puntoA(1),puntoB(1)),max(puntoA(1),puntoB(1))]];

        end
    end

    puntoA=s(ns).puntos(s(ns).numero,:);
    puntoB=s(ns).puntos(1,:);

    if abs(puntoA(1)-puntoB(1))<10^(-15)
        s(ns).tipo=strvcat(s(ns).tipo,'Paralela al Eje z');
        s(ns).poligonal=[s(ns).poligonal;[puntoA(1),0]];
        s(ns).limites=[s(ns).limites;[min(puntoA(2),puntoB(2)),max(puntoA(2),puntoB(2))]];
    elseif abs(puntoA(2)-puntoB(2))<10^(-15)
        s(ns).tipo=strvcat(s(ns).tipo,'Paralela al Eje y');
        s(ns).poligonal=[s(ns).poligonal;[puntoA(2),0]];
        s(ns).limites=[s(ns).limites;[min(puntoA(1),puntoB(1)),max(puntoA(1),puntoB(1))]];
    else
        s(ns).tipo=strvcat(s(ns).tipo,'Oblicua');
        a=(puntoA(1)-puntoB(1))/(puntoA(2)-puntoB(2));
        b=puntoA(1)-a*puntoA(2);
        s(ns).poligonal=[s(ns).poligonal;[a,b]];
        s(ns).limites=[s(ns).limites;[min(puntoA(1),puntoB(1)),max(puntoA(1),puntoB(1))]];

    end



    m=m+s(ns).numero+1;

end
