function [dnec,dg,sal,caladok]=saludo(fichero,v,Xg,hang,dang,alfa,varargin)

% Este fichero comprueba si en la botadura hay o no saludo.
%
% [dnec,dg,sal,caladok]=saludo(fichero,v,Xg,hang,dang,alfa,varargin);
%
% % Variables de entrada:
% fichero archivo excel que contiene los valores hidrostticos necesarios
%         a diferentes calados
% v  vector que contiene los valores hidrostticos necesarios para
%    el calado de flotacin
% Xg coordenada x del centro de gravedad del barco real
% hang altura de la anguila
% dang distancia desde la proa de la anguila a la proa del barco
% alfa inclinacin de la grada
% varargin
%           posibilidad '1', dg (distancia mojada de la grada)
%           posibilidad '2', caladok (calado en el punto k de la grada)
%
% Variables de salida:
% dnec distancia necesaria para que no haya saludo
% dg distancia mojada de la grada
% sal variable que indica si hay saludo (sal=1) o no (sal=0)
% caladok calado en el punto K de la grada



if varargin{1}=='1'
    dg=varargin{2};
    caladok=sin(alfa)*dg;
elseif varargin{1}=='2'
    caladok=varargin{2};
    dg=caladok/sin(alfa);
end


% Calculamos el calado de proa, y el ngulo beta de inclinacin del barco

[Tpr, Tpp, beta]=obtencion_calados(fichero,v,Xg);


% Calculamos la distancia de grada necesaria

dnec=(Tpr+dang*tan(beta)+hang)/tan(alfa);

% Comprobamos si hay saludo o no

if dnec <= dg

    sal='0';
    IconoOk=imread('IconoOk.jpg');
    uiwait(msgbox('No hay Saludo','Determinacin de Saludo','custom',IconoOk));

else

    sal='1';
    uiwait(msgbox('Cuidado, hay Saludo','Determinacin de Saludo','error'));

end
